@@ -1,5 +1,6 @@
 from __future__ import with_statement
 
+import collections
 import os
 import re
 import itertools
@@ -54,6 +55,16 @@ def get_hosts(args, logger=None):
             continue
         hosts[host] = data
 
+    hosts = collections.OrderedDict(sorted(hosts.items()))
+
+    if args.quantity is not None:
+        x = itertools.islice(hosts.items(), 0, int(args.quantity))
+        hosts = {}
+        for key, value in x:
+            hosts[key] = value
+
+        hosts = collections.OrderedDict(sorted(hosts.items()))
+
     return hosts
 
 
